"""
Created on Sat Nov 21 15:33:22 2020

author: N. Abrate.

file: .py

description:
"""
import numpy as np
import matplotlib as mpl
import matplotlib.pyplot as plt
from matplotlib import rcParams
from matplotlib import rc
# rcParams['text.usetex'] = True
rcParams['figure.dpi'] = 200
rc('font', **{'family': 'serif', 'serif': ['Computer Modern']})
rc('text', usetex=True)

E_min, E_max = 1e-11, 20
E_2, E_3, E_4 = 1e-07, 1e-05, 10

NP = 1500
N_therm = 20
N_fast = 10
N_epi = NP-N_therm-N_fast+2
EG_thermal = np.concatenate([[E_min], np.exp(np.linspace(np.log(E_2), np.log(E_3), N_therm))])
EG_epithermal = np.exp(np.linspace(np.log(E_3), np.log(E_4), N_epi))
EG_fast = np.exp(np.linspace(np.log(E_4), np.log(E_max), N_fast))
E = np.concatenate([EG_thermal, EG_epithermal, EG_fast])
E = np.unique(E)

E33 = np.loadtxt('33G.txt')*1E-6
coarseE = np.array([1e-11, 2e-5, 9.1188e-3, 6.7379e-2, 1.8316e-1, 1.353, 20])

xs, ys = E, E
ax = plt.gca()
# grid lines
for x in xs:
    p1, = plt.plot([x, x], [0, 1], color='black', alpha=.7, linewidth=0.1, label='1500G')
for y in ys:
    plt.plot([xs[0], xs[-1]], [y, y], color='black', alpha=.7, linewidth=0.1)

xs, ys = E33, E33
for x in xs:
    p2, = plt.plot([x, x], [0, 1], color='blue', linewidth=1, ls='--', label='33G')
for y in ys:
    plt.plot([xs[0], xs[-1]], [y, y], color='blue', linewidth=1, ls='--')

xs, ys = coarseE, coarseE
for x in xs:
    p3, = plt.plot([x, x], [0, 1], color='red', linewidth=1, ls='-.', label='6G')
for y in ys:
    plt.plot([xs[0], xs[-1]], [y, y], color='red', linewidth=1, ls='-.')

ax.set_aspect('equal')
ax.set_xscale('log')
ax.set_yscale('log')
ax.set_xlabel('energy [MeV]')
ax.set_ylabel('energy [MeV]')
ax.set_xlim([1E-11, 20])
ax.set_ylim([1E-11, 20])
plt.legend(handles=[p1, p2, p3], bbox_to_anchor=(1.05, 1), loc='upper left')
plt.savefig('covariance_grid_all.png')
